==> pointpos_api-0.0.16.tar.gz: test/discount_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for DiscountApi
void main() {
  var instance = new DiscountApi();

  group('tests for DiscountApi', () {
    // Create Discount
    //
    // Create Discount
    //
    //Future<Discount> createDiscount(String authorization, String xAPIKey, Discount body, { String xPin }) async 
    test('test createDiscount', () async {
      // TODO
    });

    // Delete Discount By ID
    //
    // Delete Discount By ID
    //
    //Future deleteDiscountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteDiscountByID', () async {
      // TODO
    });

    // Get Discount List
    //
    // Get Discount  List
    //
    //Future<List<Discount>> findDiscount(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findDiscount', () async {
      // TODO
    });

    // Get Discount By ID
    //
    // Get Discount By ID
    //
    //Future<Discount> getDiscountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getDiscountByID', () async {
      // TODO
    });

    // Update Discount By ID
    //
    // Update [object Object] By ID
    //
    //Future<Discount> updateDiscountByID(String authorization, String xAPIKey, String id, Discount body, { String xPin }) async 
    test('test updateDiscountByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/discount_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for DiscountApi
void main() {
  var instance = new DiscountApi();

  group('tests for DiscountApi', () {
    // Create Discount
    //
    // Create Discount
    //
    //Future<Discount> createDiscount(String authorization, String xAPIKey, Discount body, { String xPin }) async 
    test('test createDiscount', () async {
      // TODO
    });

    // Delete Discount By ID
    //
    // Delete Discount By ID
    //
    //Future deleteDiscountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteDiscountByID', () async {
      // TODO
    });

    // Get Discount List
    //
    // Get Discount  List
    //
    //Future<List<Discount>> findDiscount(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findDiscount', () async {
      // TODO
    });

    // Get Discount By ID
    //
    // Get Discount By ID
    //
    //Future<Discount> getDiscountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getDiscountByID', () async {
      // TODO
    });

    // Update Discount By ID
    //
    // Update [object Object] By ID
    //
    //Future<Discount> updateDiscountByID(String authorization, String xAPIKey, String id, Discount body, { String xPin }) async 
    test('test updateDiscountByID', () async {
      // TODO
    });

  });
}
